'''
Created on 28 avr. 2021

@author: laborie
'''
from django.utils import timezone
from django.apps import apps
from datetime import timedelta
from mri_users.models import NewUser, ChangePasswdLink, WaitingValidationMails,\
    MailsModels
from MRIOutils import settings
from django.forms.models import model_to_dict
if apps.is_installed('mri_db_logger'):
    from mri_db_logger.models import ActionsLogs


def manage_model_entry_validity(sender, **kwargs):
    '''
    Fonction executé apres chaque requete
    On gere ici l'expiration des liens et newuser
    '''
    # Efface les liens de changement de mdp expiré
    time_threshold = timezone.now() - timedelta(hours=settings.RESET_LINK_PWD_HOUR_VALIDITY)
    passwd_link = ChangePasswdLink.objects.filter(send_on__lt=time_threshold)
    if passwd_link and apps.is_installed('mri_db_logger'):
        for link in passwd_link:
            ActionsLogs.objects.create(action='Delete expired passwd link',
                                       infos={'username': link.user.username})
    passwd_link.delete()
    # Efface les liens de validation de changement de mails
    waiting_validation_mails = WaitingValidationMails.objects.filter(changed_date__lt=time_threshold,
                                                                     email_confirmed=False)
    if waiting_validation_mails and apps.is_installed('mri_db_logger'):
        for mail in waiting_validation_mails:
            infos = {'username': mail.user.username,
                     'old_mail': mail.user.email,
                     'new_mail': mail.new_email}
            ActionsLogs.objects.create(action='Delete expired change mail',
                                       infos=infos)
    waiting_validation_mails.delete()
    # Efface les nouvelles inscriptions avec liens de validation expiré
    time_threshold = timezone.now() - timedelta(hours=settings.NEWUSER_VALIDATE_EMAIL_HOUR_VALIDITY)
    newusers = NewUser.objects.filter(email_confirmed=False, inscription_date__lt=time_threshold)
    if newusers and apps.is_installed('mri_db_logger'):
        for newuser in newusers:
            infos = model_to_dict(newuser)
            ActionsLogs.objects.create(action='Delete expired newuser',
                                       infos=infos)
    newusers.delete()


def delete_mail_draft(sender, **kwargs):
    '''
    Methode executé au debut de chaque requetes afin de supprimer les brouillons
    de mail expiré
    '''
    MailsModels.objects.filter(test_for__isnull=False, last_updated__lt=timezone.now()-timedelta(minutes=60)).delete()

